# Repository path:    $HeadURL: https://90.145.156.222/DMS-Houtribdijk/code/python-ftp-svn/source/DataFeedStatus.py $
# Last committed:     $Revision: 208452 $; $Author: svcdms $; $Date: 2019-07-09 11:54:44 +0200 (di, 09 jul 2019) $
#
from datetime import datetime
from json import load, dump, JSONDecodeError


class DataFeedStatus:
    def __init__(self, status_file, logger):
        self._status_file = status_file
        self._logger = logger

    def get_timestamp_from_file(self):
        self._logger.debug("DataFeedStatus.get_timestamp_from_file({})".format(self._status_file))
        try:
            with open(self._status_file) as json_file:
                data_timestamp = load(json_file)
                try:
                    return {'fn': data_timestamp['fn'], 'ts': datetime.strptime(data_timestamp['ts'], "%Y-%m-%d %H:%M:%S")}
                except KeyError:
                    self._logger.warning("DataFeedStatus.get_timestamp_from_file: Timestamp file {} does not contain the expected keys".format(self._status_file))
                    return {'fn': '', 'ts': datetime(year=1970, month=1, day=1)}
        except FileNotFoundError:
            self._logger.warning("DataFeedStatus.get_timestamp_from_file: Timestamp file {} not found".format(self._status_file))
            return {'fn': '', 'ts': datetime(year=1970, month=1, day=1)}
        except JSONDecodeError:
            self._logger.warning("DataFeedStatus.get_timestamp_from_file: Timestamp file {} is not a valid json file".format(self._status_file))
            return {'fn': '', 'ts': datetime(year=1970, month=1, day=1)}
        except ValueError:
            self._logger.warning("DataFeedStatus.get_timestamp_from_file: Timestamp in file {} is not valid".format(self._status_file))
            return {'fn': '', 'ts': datetime(year=1970, month=1, day=1)}

    def update_timestamp_file(self, fn, ts):
        self._logger.debug("DataFeedStatus.update_timestamp_file({},{},{})".format(fn, ts, self._status_file))
        with open(self._status_file, 'w') as outfile:
            dump({'fn': fn, 'ts': ts.__str__()}, outfile)
